libnauty: Find automorphism groups of graphs, generate non-isomorphic graphs (callable library)
===============================================================================================

Description
-----------

Nauty has various tools for finding the automorphism group of a graph,
generating non-isomorphic graphs with certain properties, etc.

This script package represents the callable library of nauty.

License
-------

Since version 2.6, nauty license is GPL-compatible, see

http://users.cecs.anu.edu.au/~bdm/nauty/COPYRIGHT.txt

(a copy of this file, called COPYRIGHT, is also present in the tarball)

Special Packaging Instruction
-----------------------------

Upstream distribute tarball named nauty${version}.tar.gz. We cannot deal
with that so rename it nauty-${version}.tar.gz (notice the "-") without
any changes.

Upstream Contact
----------------

Brendan D. McKay Computer Science Department Australian National
University bdm@cs.anu.edu.au

Adolfo Piperno Dipartimento di Informatica Sapienza - Università di Roma
piperno@di.uniroma1.it

See http://cs.anu.edu.au/~bdm/nauty/ or http://pallini.di.uniroma1.it/
